@@ -47,9 +47,9 @@
 // Some internal constants
 #define CREATE_LIFE_CYCLE "01"
 
-#define KDM_CONTROL_FIFO_DIR "/tmp/ksocket-global/kdm"
-#define KDM_CONTROL_FIFO_FILE "/tmp/ksocket-global/kdm/kdmctl-%1"
-#define KDM_CONTROL_FIFO_SAK_FILE "/tmp/ksocket-global/kdm/kdmctl-sak-%1"
+#define TDM_CONTROL_FIFO_DIR "/tmp/tdesocket-global/tdm"
+#define TDM_CONTROL_FIFO_FILE "/tmp/tdesocket-global/tdm/tdmctl-%1"
+#define TDM_CONTROL_FIFO_SAK_FILE "/tmp/tdesocket-global/tdm/tdmctl-sak-%1"
 
 // In ckpass.o
 extern "C" {
@@ -228,6 +228,8 @@ TQString get_file(TQString prefix, TQString mode) {
 		usleep(100000);	// [FIXME] Here I assume that the entire file will be written (after it was created) within 100us.  This may not be correct in all cases!
 		return TQString("3F00_%1").arg(file);
 	}
+
+	return TQString("");
 }
 
 void createfile(TQString prefix, TQString mode)
@@ -362,7 +364,7 @@ int main (int argc, char *argv[])
 		int output = systemexec("echo \"exit\" | timeout 1 scriptor 2>/dev/null 1>/dev/null");
 		if (output == 0) {
 			printf("[DEBUG 400.1] Card inserted!\n"); fflush(stdout);
-			systemexec("echo \"TAuthenticating SmartCard...\" > /tmp/ksocket-global/kdesktoplockcontrol &");
+			systemexec("echo \"TAuthenticating SmartCard...\" > /tmp/tdesocket-global/kdesktoplockcontrol &");
 	
 			// Get card ATR
 			systemexec((TQString("echo \"RESET\" > %1/query").arg(secure_directory)).ascii());
@@ -494,7 +496,7 @@ int main (int argc, char *argv[])
 			}
 			else {
 				printf("[DEBUG 400.7] This card does not recognize this system!\n"); fflush(stdout);
-				systemexec("echo \"EInvalid SmartCard Inserted\" > /tmp/ksocket-global/kdesktoplockcontrol &");
+				systemexec("echo \"EInvalid SmartCard Inserted\" > /tmp/tdesocket-global/kdesktoplockcontrol &");
 				sleep(1);
 				smartcard_username="";
 				unlink((TQString("%1/password").arg(secure_directory)).ascii());
@@ -538,7 +540,7 @@ int main (int argc, char *argv[])
 			int waserror=0;
 			int noactivesessions=0;
 
-			result = exec(TRINITY_BIN_PREFIX "kdmctl -g list");
+			result = exec(TRINITY_BIN_PREFIX "tdmctl -g list");
 			if (result == "ok") {
 				noactivesessions=1;
 				result="okbutempty";
@@ -547,7 +549,7 @@ int main (int argc, char *argv[])
 			TQString resultbkp=result;
 	
 			if (errcode == 0) {
-				// Allow KDM to finish starting
+				// Allow TDM to finish starting
 				if (waserror == 1) {
 					sleep(10);
 				}
@@ -582,10 +584,10 @@ int main (int argc, char *argv[])
 							if (check_password(smartcard_username.ascii(), smartcard_password.ascii()) == 0) {
 								systemexec((TQString("su %1 -c \"export DISPLAY=%2; " TRINITY_BIN_PREFIX "dcop kdesktop KScreensaverIface quit\"").arg(smartcard_username).arg(udisplay)).ascii());
 								systemexec((TQString("su %1 -c \"export DISPLAY=%2; " TRINITY_BIN_PREFIX "dcop kdesktop KScreensaverIface enable false\"").arg(smartcard_username).arg(udisplay)).ascii());
-								systemexec((TQString(TRINITY_BIN_PREFIX "kdmctl activate %1").arg(udisplay)).ascii());
+								systemexec((TQString(TRINITY_BIN_PREFIX "tdmctl activate %1").arg(udisplay)).ascii());
 							}
 							else {
-								systemexec("echo \"EUnauthorized SmartCard Inserted\" > /tmp/ksocket-global/kdesktoplockcontrol &");
+								systemexec("echo \"EUnauthorized SmartCard Inserted\" > /tmp/tdesocket-global/kdesktoplockcontrol &");
 							}
 						}
 						else {
@@ -600,7 +602,7 @@ int main (int argc, char *argv[])
 				if (foundsession == 0) {
 					printf("[DEBUG 400.c] Existing session not found, starting new...\n"); fflush(stdout);
 
-					// Get directory listing of kdm control socket directory
+					// Get directory listing of tdm control socket directory
 					// Also start new X server if needed
 					bool have_valid_display = false;
 					bool display_has_sak = false;
@@ -609,7 +611,7 @@ int main (int argc, char *argv[])
 					while (have_valid_display == false) {
 						display_has_sak = false;
 						writeerror = false;
-						TQDir dr(KDM_CONTROL_FIFO_DIR);
+						TQDir dr(TDM_CONTROL_FIFO_DIR);
 						dr.setFilter( TQDir::System );
 						dr.setSorting( TQDir::Name );
 						const TQFileInfoList *list = dr.entryInfoList();
@@ -622,8 +624,8 @@ int main (int argc, char *argv[])
 								TQString tempdisplaystr;
 								tempdisplaystr = fi->fileName();
 								printf( "%s\n", fi->fileName().latin1() ); fflush(stdout);
-								if (fi->fileName().contains("kdmctl-sak-")) {
-									tempdisplaystr = tempdisplaystr.replace("kdmctl-sak-", "");
+								if (fi->fileName().contains("tdmctl-sak-")) {
+									tempdisplaystr = tempdisplaystr.replace("tdmctl-sak-", "");
 									tempdisplayint = tempdisplaystr.toInt(&isint);
 									if (isint) {
 										if (tempdisplayint < newdisplayint) {
@@ -632,8 +634,8 @@ int main (int argc, char *argv[])
 										}
 									}
 								}
-								else if (fi->fileName().contains("kdmctl-")) {
-									tempdisplaystr = tempdisplaystr.replace("kdmctl-", "");
+								else if (fi->fileName().contains("tdmctl-")) {
+									tempdisplaystr = tempdisplaystr.replace("tdmctl-", "");
 									tempdisplayint = tempdisplaystr.toInt(&isint);
 									if (isint) {
 										if (tempdisplayint < newdisplayint) {
@@ -645,10 +647,10 @@ int main (int argc, char *argv[])
 								++it;
 							}
 							if (display_has_sak) {
-								if (writefile(TQString(KDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint), "CLOSE\n") < 0) {
+								if (writefile(TQString(TDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint), "CLOSE\n") < 0) {
 									// Uh oh, something failed...
-									printf("Unable to write to KDM control socket %s\n", (TQString(KDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
-									unlink((TQString(KDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint)).ascii());
+									printf("Unable to write to TDM control socket %s\n", (TQString(TDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
+									unlink((TQString(TDM_CONTROL_FIFO_SAK_FILE).arg(newdisplayint)).ascii());
 									writeerror = true;
 								}
 								else {
@@ -656,7 +658,7 @@ int main (int argc, char *argv[])
 									int status = -1;
 									int timeout_counter = 0;
 									while ((status != 0) && (timeout_counter < 30)) {
-										status = stat((TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii(), &buffer);
+										status = stat((TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii(), &buffer);
 										timeout_counter++;
 										usleep(100000);
 									}
@@ -664,16 +666,16 @@ int main (int argc, char *argv[])
 							}
 							else {
 								// Make sure the control socket is writable
-								if (writefile(TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint), "PING\n") < 0) {
+								if (writefile(TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint), "PING\n") < 0) {
 									// Uh oh, something failed...
-									printf("Unable to write to KDM control socket %s\n", (TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
-									unlink((TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii());
+									printf("Unable to write to TDM control socket %s\n", (TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
+									unlink((TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii());
 									writeerror = true;
 								}
 							}
 							if (newdisplayint == (MAXIMUM_VTS+1)) {
 								writeerror = true;
-								systemexec(TRINITY_BIN_PREFIX "kdmctl -g reserve");
+								systemexec(TRINITY_BIN_PREFIX "tdmctl -g reserve");
 								usleep(3000000);
 							}
 							if (writeerror)
@@ -683,7 +685,7 @@ int main (int argc, char *argv[])
 						}
 						else
 						{
-							// KDM is probably not running yet, as its control directory does not exist
+							// TDM is probably not running yet, as its control directory does not exist
 							// Wait for 10 seconds and try again
 							usleep(10000000);
 						}
@@ -694,12 +696,12 @@ int main (int argc, char *argv[])
 
 					// Construct login string
 					TQString logincommand = TQString("LOGIN\t%1\t%2\n").arg(smartcard_username).arg(smartcard_password);
-					if (writefile(TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint), logincommand) < 0) {
+					if (writefile(TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint), logincommand) < 0) {
 						// Uh oh, something failed...
-						printf("Unable to write to KDM control socket %s\n", (TQString(KDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
+						printf("Unable to write to TDM control socket %s\n", (TQString(TDM_CONTROL_FIFO_FILE).arg(newdisplayint)).ascii()); fflush(stdout);
 					}
 
-					systemexec((TQString(TRINITY_BIN_PREFIX "kdmctl -g activate %1").arg(newdisplay)).ascii());
+					systemexec((TQString(TRINITY_BIN_PREFIX "tdmctl -g activate %1").arg(newdisplay)).ascii());
 					udisplay=newdisplay;
 				}
 
@@ -713,7 +715,7 @@ int main (int argc, char *argv[])
 		
 				// if (loginok == 1) {
 					// Wait for SmartCard removal
-					systemexec("echo \"C\" > /tmp/ksocket-global/kdesktoplockcontrol &");
+					systemexec("echo \"C\" > /tmp/tdesocket-global/kdesktoplockcontrol &");
 					timer=60;
 					output=0;
 					
@@ -765,7 +767,7 @@ int main (int argc, char *argv[])
 					result="ok";
 					timeout=0;
 					errcode=0;
-					result = exec(TRINITY_BIN_PREFIX "kdmctl -g list");
+					result = exec(TRINITY_BIN_PREFIX "tdmctl -g list");
 					if (result == "ok") {
 						noactivesessions=1;
 						result="okbutempty";
@@ -800,7 +802,7 @@ int main (int argc, char *argv[])
 								timeout=0;
 								blankresult="";
 								while (blankresult != "true") {
-									systemexec((TQString(TRINITY_BIN_PREFIX "kdmctl -g activate %1").arg(udisplay)).ascii());
+									systemexec((TQString(TRINITY_BIN_PREFIX "tdmctl -g activate %1").arg(udisplay)).ascii());
 									systemexec((TQString("su %1 -c \"export DISPLAY=%2; " TRINITY_BIN_PREFIX "dcop kdesktop KScreensaverIface enable true\"").arg(smartcard_username).arg(udisplay)).ascii());
 									systemexec((TQString("su %1 -c \"export DISPLAY=%2; " TRINITY_BIN_PREFIX "dcop kdesktop KScreensaverIface lock\"").arg(smartcard_username).arg(udisplay)).ascii());
 									int retcode;
@@ -833,7 +835,7 @@ int main (int argc, char *argv[])
 	
 			smartcard_username="";
 			unlink("/etc/smartmon/minutesremaining");
-			systemexec("echo \"C\" > /tmp/ksocket-global/kdesktoplockcontrol &");
+			systemexec("echo \"C\" > /tmp/tdesocket-global/kdesktoplockcontrol &");
 		}
 	}
 }
